@@ -174,7 +174,7 @@ class TableSystem(object):
         return dt_boxes, rec_res, det_elapse, rec_elapse
 
 def to_excel(html_table, excel_path):
-    from tablepyxl import tablepyxl
+    from structure.tablepyxl import tablepyxl
     tablepyxl.document_to_xl(html_table, excel_path)
 
 def draw_boxes(image, boxes, scores=None, drop_score=0.5):
